==> jc-1.4.0.tar.gz: javax/swing/plaf/basic/BasicComboBoxUI__24KeyHandler.h <==
// public class javax.swing.plaf.basic.BasicComboBoxUI$KeyHandler

// class file dependencies
// @dep_class b920d196013f4f61 java_awt_event_KeyAdapter
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class ee0b9d322e53e86 javax_swing_plaf_basic_BasicComboBoxUI__24KeyHandler

// header file dependencies
// @dep_header java_awt_event_KeyAdapter

#include "java/awt/event/KeyAdapter.h"

#ifndef _JC_javax_swing_plaf_basic_BasicComboBoxUI__24KeyHandler_H_
#define _JC_javax_swing_plaf_basic_BasicComboBoxUI__24KeyHandler_H_

// Forward structure declarations
struct _jc_java_awt_event_KeyEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_plaf_basic_BasicComboBoxUI$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24KeyHandler$sub_refs	_jc_javax_swing_plaf_basic_BasicComboBoxUI__24KeyHandler$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24KeyHandler$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicComboBoxUI__24KeyHandler$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24KeyHandler$refs	_jc_javax_swing_plaf_basic_BasicComboBoxUI__24KeyHandler$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24KeyHandler$nonrefs	_jc_javax_swing_plaf_basic_BasicComboBoxUI__24KeyHandler$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24KeyHandler$object	_jc_javax_swing_plaf_basic_BasicComboBoxUI__24KeyHandler$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24KeyHandler$vmethods	_jc_javax_swing_plaf_basic_BasicComboBoxUI__24KeyHandler$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24KeyHandler$vtable	_jc_javax_swing_plaf_basic_BasicComboBoxUI__24KeyHandler$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24KeyHandler$vtype	_jc_javax_swing_plaf_basic_BasicComboBoxUI__24KeyHandler$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicComboBoxUI__24KeyHandler$method$_init$2bc13d637ee2ba7f(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24KeyHandler$object *, struct _jc_javax_swing_plaf_basic_BasicComboBoxUI$object *);

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicComboBoxUI__24KeyHandler$method$keyPressed$d7fe1c88a82640ee(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24KeyHandler$object *, struct _jc_java_awt_event_KeyEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicComboBoxUI__24KeyHandler$method_info$keyPressed$d7fe1c88a82640ee;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24KeyHandler$vmethods {
	void	(*keyPressed$d7fe1c88a82640ee)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24KeyHandler$object *, struct _jc_java_awt_event_KeyEvent$object *);
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24KeyHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_event_KeyAdapter$vmethods	java_awt_event_KeyAdapter;
	_jc_javax_swing_plaf_basic_BasicComboBoxUI__24KeyHandler$vmethods	javax_swing_plaf_basic_BasicComboBoxUI__24KeyHandler;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24KeyHandler$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicComboBoxUI__24KeyHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24KeyHandler$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicComboBoxUI$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24KeyHandler$refs {
    _jc_javax_swing_plaf_basic_BasicComboBoxUI__24KeyHandler$sub_refs	javax_swing_plaf_basic_BasicComboBoxUI__24KeyHandler;
    _jc_java_awt_event_KeyAdapter$sub_refs	java_awt_event_KeyAdapter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24KeyHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24KeyHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_event_KeyAdapter$sub_nonrefs	java_awt_event_KeyAdapter;
    _jc_javax_swing_plaf_basic_BasicComboBoxUI__24KeyHandler$sub_nonrefs	javax_swing_plaf_basic_BasicComboBoxUI__24KeyHandler;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24KeyHandler$object {
	_jc_javax_swing_plaf_basic_BasicComboBoxUI__24KeyHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicComboBoxUI__24KeyHandler$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicComboBoxUI__24KeyHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicComboBoxUI__24KeyHandler$vtype _jc_javax_swing_plaf_basic_BasicComboBoxUI__24KeyHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicComboBoxUI__24KeyHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicComboBoxUI__24KeyHandler$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicComboBoxUI__24KeyHandler_H_ */

==> jc-1.4.6.tar.gz: javax/swing/plaf/basic/BasicComboBoxUI__24KeyHandler.h <==
// public class javax.swing.plaf.basic.BasicComboBoxUI$KeyHandler

// class file dependencies
// @dep_class b920d196013f4f61 java_awt_event_KeyAdapter
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d324c916d935fcdc javax_swing_plaf_basic_BasicComboBoxUI__24KeyHandler

// header file dependencies
// @dep_header java_awt_event_KeyAdapter

#include "java/awt/event/KeyAdapter.h"

#ifndef _JC_javax_swing_plaf_basic_BasicComboBoxUI__24KeyHandler_H_
#define _JC_javax_swing_plaf_basic_BasicComboBoxUI__24KeyHandler_H_

// Forward structure declarations
struct _jc_java_awt_event_KeyEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_plaf_basic_BasicComboBoxUI$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24KeyHandler$sub_refs	_jc_javax_swing_plaf_basic_BasicComboBoxUI__24KeyHandler$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24KeyHandler$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicComboBoxUI__24KeyHandler$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24KeyHandler$refs	_jc_javax_swing_plaf_basic_BasicComboBoxUI__24KeyHandler$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24KeyHandler$nonrefs	_jc_javax_swing_plaf_basic_BasicComboBoxUI__24KeyHandler$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24KeyHandler$object	_jc_javax_swing_plaf_basic_BasicComboBoxUI__24KeyHandler$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24KeyHandler$vmethods	_jc_javax_swing_plaf_basic_BasicComboBoxUI__24KeyHandler$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24KeyHandler$vtable	_jc_javax_swing_plaf_basic_BasicComboBoxUI__24KeyHandler$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24KeyHandler$vtype	_jc_javax_swing_plaf_basic_BasicComboBoxUI__24KeyHandler$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicComboBoxUI__24KeyHandler$method$_init$2bc13d637ee2ba7f(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24KeyHandler$object *, struct _jc_javax_swing_plaf_basic_BasicComboBoxUI$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicComboBoxUI__24KeyHandler$method$keyPressed$d7fe1c88a82640ee(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24KeyHandler$object *, struct _jc_java_awt_event_KeyEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicComboBoxUI__24KeyHandler$method_info$keyPressed$d7fe1c88a82640ee;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24KeyHandler$vmethods {
	void	(*keyPressed$d7fe1c88a82640ee)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24KeyHandler$object *, struct _jc_java_awt_event_KeyEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24KeyHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_event_KeyAdapter$vmethods	java_awt_event_KeyAdapter;
	_jc_javax_swing_plaf_basic_BasicComboBoxUI__24KeyHandler$vmethods	javax_swing_plaf_basic_BasicComboBoxUI__24KeyHandler;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24KeyHandler$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicComboBoxUI__24KeyHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24KeyHandler$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicComboBoxUI$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24KeyHandler$refs {
    _jc_javax_swing_plaf_basic_BasicComboBoxUI__24KeyHandler$sub_refs	javax_swing_plaf_basic_BasicComboBoxUI__24KeyHandler;
    _jc_java_awt_event_KeyAdapter$sub_refs	java_awt_event_KeyAdapter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24KeyHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24KeyHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_event_KeyAdapter$sub_nonrefs	java_awt_event_KeyAdapter;
    _jc_javax_swing_plaf_basic_BasicComboBoxUI__24KeyHandler$sub_nonrefs	javax_swing_plaf_basic_BasicComboBoxUI__24KeyHandler;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicComboBoxUI__24KeyHandler$object {
	_jc_javax_swing_plaf_basic_BasicComboBoxUI__24KeyHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicComboBoxUI__24KeyHandler$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicComboBoxUI__24KeyHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicComboBoxUI__24KeyHandler$vtype _jc_javax_swing_plaf_basic_BasicComboBoxUI__24KeyHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicComboBoxUI__24KeyHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicComboBoxUI__24KeyHandler$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicComboBoxUI__24KeyHandler_H_ */
